==> git-cola_3.1.orig.tar.gz: git-cola-3.1/share/git-cola/icons/README.md <==
Git Cola Icons
--------------
The following icons are based on the based on the original .png icon designs
for git-cola's File Browser by Uri Okrent.

staged.svg
modified.svg
partial.svg
upstream.svg

Copyright (C) 2011 Uri Okrent
Copyright (C) 2015-2017 David Aguilar and contributors

License: MIT


Git Logo
--------
Git Logo by Jason Long is licensed under the
Creative Commons Attribution 3.0 Unported License.
http://git-scm.com/downloads/logos

git-cola.svg is based on the original Git Logo.


Octicons
--------
The following files are from Github's
[octicons](https://github.com/github/octicons) icon set:

check.svg
circle-slash.svg
desktop-download.svg
diff.svg
ellipsis.svg
eye.svg
file-binary.svg
file-code.svg
file-directory.svg
file-media.svg
file-text.svg
file-zip.svg
fold.svg
gear.svg
git-branch.svg
git-compare.svg
git-merge.svg
link-external.svg
pencil.svg
plus.svg
primitive-dot.svg
question.svg
question-plain.svg
repo-pull.svg
repo-push.svg
repo.svg
screen-full.svg
search.svg
star.svg
sync.svg
tag.svg
telescope.svg
trashcan.svg
unfold.svg
x.svg

Copyright (C) 2012-2015 GitHub
License: [MIT](http://choosealicense.com/licenses/mit/)

Feathericons
------------
The following files are from the
[feather](https://github.com/feathericons/feather) icon set:

git-commit.svg

Copyright (c) 2013-2017 Cole Bemis
License: [MIT](https://github.com/feathericons/feather/blob/master/LICENSE)

Gnome High Contrast Icons
-------------------------
The following files are from the Gnome High Contrast Icon set:

zoom-fit-best.svg
zoom-in.svg
zoom-out.svg

License: LGPL v2+


Flaticon.com Icons
------------------

The following files are designed by Freepik from http://www.flaticons.com/

edit-undo.svg

License: [Flatpik Basic License](http://cdn.flaticon.com/license/license.pdf)


The following files are by Linh Pham from http://flaticons.com/

edit-copy.svg

License: [Creative Commons BY 3.0](http://creativecommons.org/licenses/by/3.0/)


Google Icons
------------

The following files are by Google:

edit-select-all.svg
file-download.svg

License: [Creative Commons BY 3.0](http://creativecommons.org/licenses/by/3.0/)

==> git-cola_3.3.orig.tar.gz: git-cola-3.3/share/git-cola/icons/README.md <==
Git Cola Icons
--------------
The following icons are based on the based on the original .png icon designs
for git-cola's File Browser by Uri Okrent.

staged.svg
modified.svg
partial.svg
upstream.svg

Copyright (C) 2011 Uri Okrent
Copyright (C) 2015-2017 David Aguilar and contributors

License: MIT


Git Logo
--------
Git Logo by Jason Long is licensed under the
Creative Commons Attribution 3.0 Unported License.
http://git-scm.com/downloads/logos

git-cola.svg is based on the original Git Logo.


Octicons
--------
The following files are from Github's
[octicons](https://github.com/github/octicons) icon set:

check.svg
circle-slash.svg
desktop-download.svg
diff.svg
ellipsis.svg
eye.svg
file-binary.svg
file-code.svg
file-directory.svg
file-media.svg
file-text.svg
file-zip.svg
fold.svg
gear.svg
git-branch.svg
git-compare.svg
git-merge.svg
link-external.svg
pencil.svg
plus.svg
primitive-dot.svg
question.svg
question-plain.svg
repo-pull.svg
repo-push.svg
repo.svg
screen-full.svg
search.svg
star.svg
sync.svg
tag.svg
telescope.svg
trashcan.svg
unfold.svg
x.svg

Copyright (C) 2012-2015 GitHub
License: [MIT](http://choosealicense.com/licenses/mit/)

Gnome Adwaita Icons
-------------------
The following files are from the Gnome project's
[Adwaita icon theme](https://github.com/GNOME/adwaita-icon-theme):

document-save-symbolic.svg

Copyright (C) The Gnome Project
License: [LGPL](https://github.com/GNOME/adwaita-icon-theme/blob/master/COPYING_LGPL)

Gnome High Contrast Icons
-------------------------
The following files are from the Gnome High Contrast Icon set:

zoom-fit-best.svg
zoom-in.svg
zoom-out.svg

License: LGPL v2+


Flaticon.com Icons
------------------

The following files are designed by Freepik from http://www.flaticons.com/

edit-undo.svg

License: [Flatpik Basic License](http://cdn.flaticon.com/license/license.pdf)


The following files are by Linh Pham from http://flaticons.com/

edit-copy.svg

License: [Creative Commons BY 3.0](http://creativecommons.org/licenses/by/3.0/)


Google Icons
------------

The following files are by Google:

edit-select-all.svg
file-download.svg

License: [Creative Commons BY 3.0](http://creativecommons.org/licenses/by/3.0/)
